@@ -4,15 +4,21 @@ import os
 import re
 import subprocess
 
-from skrt import Image, ImageComparison
+from skrt.image import Image, ImageComparison
 
 
 class Registration:
-
-    def __init__(self, fixed, moving, pfile, outdir='.', auto_reg=True, 
-                 force=False):
-        '''Register moving image to fixed image with a given elastix parameter 
-        file. 
+    def __init__(
+        self,
+        fixed,
+        moving,
+        pfile,
+        outdir='.',
+        auto_reg=True,
+        force=False
+    ):
+        '''Register moving image to fixed image with a given elastix parameter
+        file.
         Parameters:
         -----------
         fixed : Image/str
@@ -42,8 +48,8 @@ class Registration:
         self.pfiles = pfile
         if isinstance(pfile, str):
             self.pfiles = [pfile]
-        self.outdirs = [os.path.join(
-            self.outdir, os.path.basename(p).replace('.txt', ''))
+        self.outdirs = [
+            os.path.join(self.outdir, os.path.basename(p).replace('.txt', ''))
             for p in self.pfiles
         ]
         for d in self.outdirs:
@@ -51,8 +57,9 @@ class Registration:
                 os.makedirs(d)
 
         # Expected locations of outputs
-        self.tfiles = [os.path.join(d, 'TransformParameters.0.txt')
-                       for d in self.outdirs]
+        self.tfiles = [
+            os.path.join(d, 'TransformParameters.0.txt') for d in self.outdirs
+        ]
         self.tfile = self.tfiles[-1]
         self.out_path = os.path.join(self.outdirs[-1], 'result.0.nii')
 
@@ -68,7 +75,7 @@ class Registration:
 
                 path = os.path.join(self.outdir, f'{im}.nii.gz')
                 if not os.path.exists(path):
-                    setattr(self, im, ensure_image(getattr(self, im))) 
+                    setattr(self, im, ensure_image(getattr(self, im)))
                     path = get_nifti_path(getattr(self, im), path, force)
 
                 setattr(self, f'{im}_path', path)
@@ -83,7 +90,7 @@ class Registration:
         )
         if tfile is not None:
             self.cmd += f' -t0 {tfile}'
-    
+
     def register(self, force=False, apply=False):
 
         # Run elastix
@@ -98,8 +105,10 @@ class Registration:
                 # Create elastix command
                 force_nii_creation = force and i == 0
                 tfile = None if i == 0 else self.tfiles[i - 1]
-                self.create_elastix_command(pfile, self.outdirs[i], tfile=tfile,
-                                            force=force_nii_creation)
+                self.create_elastix_command(
+                    pfile, self.outdirs[i], tfile=tfile, 
+                    force=force_nii_creation
+                )
 
                 # Run elastix
                 print('Running command:', self.cmd)
@@ -125,10 +134,9 @@ class Registration:
 
         # Ensure output format is nifti
         set_parameters(
-            self.tfile, 
-            {'ResultImageFormat': '"nii"',
-             'CompressResultImage': '"false"'
-            })
+            self.tfile, {'ResultImageFormat': ''nii'', 
+                         'CompressResultImage': ''false''}
+        )
 
         cmd = f'transformix -in {im_path} -out {outdir} -tp {self.tfile}'
         print('Running command:', cmd)
@@ -144,9 +152,9 @@ class Registration:
             return self.final
 
         if not os.path.exists(self.out_path) or force:
-            self.out_path = self.transform_image(self.moving_path, 
-                                                 self.outdirs[-1], 
-                                                 force)
+            self.out_path = self.transform_image(
+                self.moving_path, self.outdirs[-1], force
+            )
         self.final = Image(self.out_path)
 
     def get_comparison(self):
@@ -163,8 +171,7 @@ class Registration:
         self.get_comparison()
         for view in ['x-y', 'y-z', 'x-z']:
             self.comparison.plot_overlay(
-                view, 
-                save_as=os.path.join(outdir, f'overlay_{view}.pdf'),
+                view, save_as=os.path.join(outdir, f'overlay_{view}.pdf'), 
                 **kwargs
             )
 
@@ -179,7 +186,7 @@ class Registration:
             Index of the parameter file to adjust (by default, this will be the
             last parameter file.
         make_copy : bool, default=True
-            If True, a new parameter file will be created in self.outdir rather 
+            If True, a new parameter file will be created in self.outdir rather
             than overwriting the original parameter file.
         '''
 
@@ -196,9 +203,11 @@ class Registration:
             self.pfiles[idx] = outfile
 
     def view_comparison(self, **kwargs):
-        '''View comparison of fixed image and final transformed moving image.'''
+        '''View comparison of fixed image and final transformed moving 
+        image.'''
+
+        from skrt.viewer import QuickViewer
 
-        from quickviewer import QuickViewer
         self.get_final_image()
         if 'comparison' not in kwargs:
             kwargs['comparison'] = True
@@ -207,15 +216,13 @@ class Registration:
             kwargs['hu'] = self.fixed.default_window
         if 'title' not in kwargs:
             kwargs['title'] = ['Fixed', 'Transformed moving']
-        QuickViewer(
-            [self.fixed_path, self.out_path],
-            **kwargs
-        )
+        QuickViewer([self.fixed_path, self.out_path], **kwargs)
 
     def view_init(self, **kwargs):
         '''View comparison of initial fixed and moving images.'''
 
-        from quickviewer import QuickViewer
+        from skrt.viewer import QuickViewer
+
         if 'hu' not in kwargs:
             self.fixed = ensure_image(self.fixed)
             kwargs['hu'] = self.fixed.default_window
@@ -223,9 +230,7 @@ class Registration:
             kwargs['match_axes'] = 'y'
         if 'title' not in kwargs:
             kwargs['title'] = ['Fixed', 'Moving']
-        QuickViewer(
-            [self.fixed_path, self.moving_path], **kwargs
-        )
+        QuickViewer([self.fixed_path, self.moving_path], **kwargs)
 
 
 def ensure_image(im):
