@@ -1,4 +1,4 @@
-'''Classes for creating synthetic images with simple geometries.'''
+"""Classes for creating synthetic images with simple geometries."""
 
 import os
 import numpy as np
@@ -6,12 +6,13 @@ import nibabel
 import shutil
 from scipy import ndimage
 
-from skrt import Image, RtStruct, ROI
-from skrt import to_three, is_list, _axes
+from skrt.image import Image, _axes
+from skrt.structures import RtStruct, ROI
+import skrt.core
 
 
 class SyntheticImage(Image):
-    '''Class for creating synthetic image data with simple geometric shapes.'''
+    """Class for creating synthetic image data with simple geometric shapes."""
 
     def __init__(
         self,
@@ -22,14 +23,14 @@ class SyntheticImage(Image):
         intensity=-1024,
         noise_std=None,
     ):
-        '''Create data to write to a NIfTI file, initially containing a
+        """Create data to write to a NIfTI file, initially containing a
         blank image array.
 
         Parameters
         ----------
         shape : int/tuple
-            Dimensions of the image array to create in order (x, y, z). 
-            If an int is given, the image will be created with dimensions 
+            Dimensions of the image array to create in order (x, y, z).
+            If an int is given, the image will be created with dimensions
             (shape, shape, shape).
 
         filename : str, default=None
@@ -49,12 +50,12 @@ class SyntheticImage(Image):
         noise_std : float, default=None
             Standard deviation of Gaussian noise to apply to the image.
             If None, no noise will be applied.
-        '''
+        """
 
         # Create image properties
-        shape = to_three(shape)
+        shape = skrt.core.to_three(shape)
         self.shape = [shape[1], shape[0], shape[2]]
-        voxel_size = [abs(v) for v in to_three(voxel_size)]
+        voxel_size = [abs(v) for v in skrt.core.to_three(voxel_size)]
         self.max_hu = 0 if noise_std is None else noise_std * 3
         self.min_hu = -self.max_hu if self.max_hu != 0 else -20
         self.noise_std = noise_std
@@ -68,32 +69,31 @@ class SyntheticImage(Image):
         self.rotation = None
 
         # Initialise as Image
-        Image.__init__(self, self.background, voxel_size=voxel_size,
-                       origin=origin)
+        Image.__init__(self, self.background, voxel_size=voxel_size, origin=origin)
 
         # Write to file if a filename is given
         if filename is not None:
             self.filename = os.path.expanduser(filename)
             self.write()
 
-    #  def view(self, **kwargs):
-        #  '''View with QuickViewer.'''
+    def view(self, **kwargs):
+        """View with QuickViewer."""
 
-        #  from quickviewer import QuickViewer
+        from skrt import QuickViewer
 
-        #  qv_kwargs = {
-            #  'hu': [self.min_hu, self.max_hu],
-            #  'title': '',
-            #  'origin': self.origin,
-            #  'voxel_size': self.voxel_size,
-            #  'mpl_kwargs': {'interpolation': 'none'},
-        #  }
-        #  qv_kwargs.update(kwargs)
-        #  structs = self.get_struct_data()
-        #  QuickViewer(self.get_data(), structs=structs, **qv_kwargs)
+        qv_kwargs = {
+            "hu": [self.min_hu, self.max_hu],
+            "title": "",
+            "origin": self.origin,
+            "voxel_size": self.voxel_size,
+            "mpl_kwargs": {"interpolation": "none"},
+        }
+        qv_kwargs.update(kwargs)
+        structs = self.get_struct_data()
+        QuickViewer(self.get_data(), structs=structs, **qv_kwargs)
 
     def get_data(self):
-        '''Get data with noise overlaid.'''
+        """Get data with noise overlaid."""
 
         # Get noiseless image
         data = self.background.copy()
@@ -107,14 +107,14 @@ class SyntheticImage(Image):
         return data
 
     def plot(self, *args, **kwargs):
-        '''Plot the current image.'''
+        """Plot the current image."""
 
         self.sdata = self.get_data()
         self.structs = [self.get_rtstruct()]
         Image.plot(self, structure_set=0, *args, **kwargs)
 
     def get_struct_data(self):
-        '''Get dict of structures and names, with any transformations applied.'''
+        """Get dict of structures and names, with any transformations applied."""
 
         struct_data = {}
         for shape in self.struct_shapes:
@@ -123,35 +123,36 @@ class SyntheticImage(Image):
         return struct_data
 
     def get_rtstruct(self):
-        '''Make RtStruct object of own structures.'''
+        """Make RtStruct object of own structures."""
 
         rtstruct = RtStruct()
         for shape in self.struct_shapes:
-            rtstruct.add_struct(shape.get_data(self.get_coords()), 
-                                name=shape.name, affine=self.affine)
+            rtstruct.add_struct(
+                shape.get_data(self.get_coords()), name=shape.name, affine=self.affine
+            )
         return rtstruct
 
     def get_struct(self, name):
-        '''Get a named structure as a Structure object.'''
+        """Get a named structure as a Structure object."""
 
         structs_dict = {s.name: s for s in self.struct_shapes}
         if name not in structs_dict:
-            print('Structure', name, 'not found!')
+            print("Structure", name, "not found!")
             return
 
         s = structs_dict[name]
         return ROI(s.get_data(self.get_coords()), name=name, affine=self.affine)
 
     def write(self, outname=None, overwrite_struct_dir=False):
-        '''Write image data to an output file.'''
+        """Write image data to an output file."""
 
         # Check filename
         if outname is None:
-            if hasattr(self, 'filename'):
+            if hasattr(self, "filename"):
                 outname = self.filename
             else:
                 raise RuntimeError(
-                    'Filename must be specified in __init__() ' 'or write()!'
+                    "Filename must be specified in __init__() " "or write()!"
                 )
 
         # Write image data
@@ -159,23 +160,22 @@ class SyntheticImage(Image):
 
         # Write structures
         rtstruct = self.get_rtstruct()
-        exts = ['.nii', '.nii.gz', '.npy']
+        exts = [".nii", ".nii.gz", ".npy"]
         outdir = outname
         ext_to_use = None
         for ext in exts:
             if outname.endswith(ext):
                 ext_to_use = ext
-                outdir = outname.replace(ext, '')
-        rtstruct.write(outdir=outdir, ext=ext_to_use, 
-                       overwrite=overwrite_struct_dir)
+                outdir = outname.replace(ext, "")
+        rtstruct.write(outdir=outdir, ext=ext_to_use, overwrite=overwrite_struct_dir)
 
     def make_background(self):
-        '''Make blank image array or noisy array.'''
+        """Make blank image array or noisy array."""
 
         return np.ones(self.shape) * self.bg_intensity
 
     def reset(self):
-        '''Remove all shapes.'''
+        """Remove all shapes."""
 
         self.shapes = []
         self.struct_shapes = []
@@ -211,7 +211,7 @@ class SyntheticImage(Image):
             self.shape_count[shape_type] += 1
 
         if shape.name is None:
-            shape.name = f'{shape_type}{self.shape_count[shape_type]}'
+            shape.name = f"{shape_type}{self.shape_count[shape_type]}"
 
         self.min_hu = min([shape.intensity, self.min_hu])
         self.max_hu = max([shape.intensity, self.max_hu])
@@ -230,13 +230,13 @@ class SyntheticImage(Image):
         if centre is None:
             centre = self.get_image_centre()
         sphere = Sphere(self.shape, radius, centre, intensity, name)
-        self.add_shape(sphere, 'sphere', is_struct, above, group)
+        self.add_shape(sphere, "sphere", is_struct, above, group)
 
     def add_cylinder(
         self,
         radius,
         length,
-        axis='z',
+        axis="z",
         centre=None,
         intensity=0,
         is_struct=None,
@@ -247,9 +247,8 @@ class SyntheticImage(Image):
 
         if centre is None:
             centre = self.get_image_centre()
-        cylinder = Cylinder(self.shape, radius, length, axis, centre, 
-                            intensity, name)
-        self.add_shape(cylinder, 'cylinder', is_struct, above, group)
+        cylinder = Cylinder(self.shape, radius, length, axis, centre, intensity, name)
+        self.add_shape(cylinder, "cylinder", is_struct, above, group)
 
     def add_cube(
         self,
@@ -279,10 +278,10 @@ class SyntheticImage(Image):
 
         if centre is None:
             centre = self.get_image_centre()
-        side_length = to_three(side_length)
+        side_length = skrt.core.to_three(side_length)
 
         cuboid = Cuboid(self.shape, side_length, centre, intensity, name)
-        self.add_shape(cuboid, 'cuboid', is_struct, above, group)
+        self.add_shape(cuboid, "cuboid", is_struct, above, group)
 
     def add_grid(
         self,
@@ -295,14 +294,16 @@ class SyntheticImage(Image):
     ):
 
         grid = Grid(self.shape, spacing, thickness, intensity, axis, name)
-        self.add_shape(grid, 'grid', False, above, group=None)
+        self.add_shape(grid, "grid", False, above, group=None)
 
     def get_coords(self):
-        '''Get grids of x, y, and z coordinates in mm for this image.'''
+        """Get grids of x, y, and z coordinates in mm for this image."""
 
-        if not hasattr(self, 'coords') \
-           or self.prev_translation != self.translation \
-           or self.prev_rotation != self.rotation:
+        if (
+            not hasattr(self, "coords")
+            or self.prev_translation != self.translation
+            or self.prev_rotation != self.rotation
+        ):
 
             # Make coordinates
             coords_1d = []
@@ -310,8 +311,7 @@ class SyntheticImage(Image):
                 coords_1d.append(
                     np.arange(
                         self.origin[i],
-                        self.origin[i] + self.voxel_size[i] 
-                        * self.n_voxels[i],
+                        self.origin[i] + self.voxel_size[i] * self.n_voxels[i],
                         self.voxel_size[i],
                     )
                 )
@@ -331,12 +331,24 @@ class SyntheticImage(Image):
                     transform = transform.dot(
                         get_rotation_matrix(*[-r for r in self.rotation], centre)
                     )
-                Yt = transform[0, 0] * Y + transform[0, 1] * X \
-                    + transform[0, 2] * Z + transform[0, 3]
-                Xt = transform[1, 0] * Y + transform[1, 1] * X \
-                    + transform[1, 2] * Z + transform[1, 3]
-                Zt = transform[2, 0] * Y + transform[2, 1] * X \
-                        + transform[2, 2] * Z + transform[2, 3]
+                Yt = (
+                    transform[0, 0] * Y
+                    + transform[0, 1] * X
+                    + transform[0, 2] * Z
+                    + transform[0, 3]
+                )
+                Xt = (
+                    transform[1, 0] * Y
+                    + transform[1, 1] * X
+                    + transform[1, 2] * Z
+                    + transform[1, 3]
+                )
+                Zt = (
+                    transform[2, 0] * Y
+                    + transform[2, 1] * X
+                    + transform[2, 2] * Z
+                    + transform[2, 3]
+                )
                 X, Y, Z = Xt, Yt, Zt
 
             # Set coords
@@ -346,7 +358,7 @@ class SyntheticImage(Image):
         return self.coords
 
     def reset_transforms(self):
-        '''Remove any rotations or translations.'''
+        """Remove any rotations or translations."""
 
         self.translation = None
         self.rotation = None
@@ -355,17 +367,17 @@ class SyntheticImage(Image):
             shape.rotation = None
 
     def translate(self, dx=0, dy=0, dz=0):
-        '''Set a translation to apply to the final image.'''
+        """Set a translation to apply to the final image."""
 
         self.translation = (dy, dx, dz)
 
     def rotate(self, yaw=0, pitch=0, roll=0):
-        '''Set a rotation to apply to the final image.'''
+        """Set a rotation to apply to the final image."""
 
         self.rotation = (yaw, pitch, roll)
 
 
-class ShapeGroup():
+class ShapeGroup:
     def __init__(self, shapes, name):
 
         self.name = name
@@ -382,8 +394,7 @@ class ShapeGroup():
         return data
 
 
-class Sphere():
-
+class Sphere:
     def __init__(self, shape, radius, centre, intensity, name=None):
 
         self.name = name
@@ -401,11 +412,11 @@ class Sphere():
         return distance_to_centre <= self.radius
 
 
-class Cuboid():
+class Cuboid:
     def __init__(self, shape, side_length, centre, intensity, name=None):
 
         self.name = name
-        self.side_length = to_three(side_length)
+        self.side_length = skrt.core.to_three(side_length)
         self.centre = centre
         self.intensity = intensity
 
@@ -419,11 +430,11 @@ class Cuboid():
             )
             return data
         except TypeError:
-            print('centre:', self.centre)
-            print('side length:', self.side_length)
+            print("centre:", self.centre)
+            print("side length:", self.side_length)
 
 
-class Cylinder():
+class Cylinder:
     def __init__(self, shape, radius, length, axis, centre, intensity, name=None):
 
         self.radius = radius
@@ -436,7 +447,7 @@ class Cylinder():
     def get_data(self, coords):
 
         # Get coordinates in each direction
-        axis_idx = {'x': 1, 'y': 0, 'z': 2}[self.axis]
+        axis_idx = {"x": 1, "y": 0, "z": 2}[self.axis]
         circle_idx = [i for i in range(3) if i != axis_idx]
         coords_c1 = coords[circle_idx[0]]
         coords_c2 = coords[circle_idx[1]]
@@ -456,12 +467,12 @@ class Cylinder():
         return data
 
 
-class Grid():
+class Grid:
     def __init__(self, shape, spacing, thickness, intensity, axis=None, name=None):
 
         self.name = name
-        self.spacing = to_three(spacing)
-        self.thickness = to_three(thickness)
+        self.spacing = skrt.core.to_three(spacing)
+        self.thickness = skrt.core.to_three(thickness)
         self.intensity = intensity
         self.axis = axis
         self.shape = shape
@@ -488,12 +499,7 @@ class Grid():
 
 
 def get_translation_matrix(dx, dy, dz):
-    return np.array([
-        [1, 0, 0, dx],
-        [0, 1, 0, dy],
-        [0, 0, 1, dz],
-        [0, 0, 0, 1]
-    ])
+    return np.array([[1, 0, 0, dx], [0, 1, 0, dy], [0, 0, 1, dz], [0, 0, 0, 1]])
 
 
 def get_rotation_matrix(yaw, pitch, roll, centre):
@@ -504,22 +510,43 @@ def get_rotation_matrix(yaw, pitch, roll, centre):
     roll = np.radians(roll)
 
     cx, cy, cz = centre
-    r1 = np.array([
-        [np.cos(yaw), -np.sin(yaw), 0, cx - cx * np.cos(yaw) + cy * np.sin(yaw)],
-        [np.sin(yaw), np.cos(yaw), 0, cy - cx * np.sin(yaw) - cy * np.cos(yaw)],
-        [0, 0, 1, 0],
-        [0, 0, 0, 1]
-    ])
-    r2 = np.array([
-        [np.cos(pitch), 0, np.sin(pitch), cx - cx * np.cos(pitch) - cz * np.sin(pitch)],
-        [0, 1, 0, 0],
-        [-np.sin(pitch), 0, np.cos(pitch), cz + cx * np.sin(pitch) - cz * np.cos(pitch)],
-        [0, 0, 0, 1]
-    ])
-    r3 = np.array([
-        [1, 0, 0, 0],
-        [0, np.cos(roll), -np.sin(roll), cy - cy * np.cos(roll) + cz * np.sin(roll)],
-        [0, np.sin(roll), np.cos(roll), cz - cy * np.sin(roll) - cz * np.cos(roll)],
-        [0, 0, 0, 1]
-    ])
+    r1 = np.array(
+        [
+            [np.cos(yaw), -np.sin(yaw), 0, cx - cx * np.cos(yaw) + cy * np.sin(yaw)],
+            [np.sin(yaw), np.cos(yaw), 0, cy - cx * np.sin(yaw) - cy * np.cos(yaw)],
+            [0, 0, 1, 0],
+            [0, 0, 0, 1],
+        ]
+    )
+    r2 = np.array(
+        [
+            [
+                np.cos(pitch),
+                0,
+                np.sin(pitch),
+                cx - cx * np.cos(pitch) - cz * np.sin(pitch),
+            ],
+            [0, 1, 0, 0],
+            [
+                -np.sin(pitch),
+                0,
+                np.cos(pitch),
+                cz + cx * np.sin(pitch) - cz * np.cos(pitch),
+            ],
+            [0, 0, 0, 1],
+        ]
+    )
+    r3 = np.array(
+        [
+            [1, 0, 0, 0],
+            [
+                0,
+                np.cos(roll),
+                -np.sin(roll),
+                cy - cy * np.cos(roll) + cz * np.sin(roll),
+            ],
+            [0, np.sin(roll), np.cos(roll), cz - cy * np.sin(roll) - cz * np.cos(roll)],
+            [0, 0, 0, 1],
+        ]
+    )
     return r1.dot(r2).dot(r3)
